module business {
	class healthwatcher.business..*;
	friend healthwatcher.aspects.distribution.HWServerDistribution;
	friend healthwatcher.aspects.persistence.HWDataCollection;

	expose :
		healthwatcher.aspects.distribution.HWServerDistribution.facadeMain();
	expose :
		healthwatcher.aspects.persistence.HWPersistence.newFacade();
	expose :
		healthwatcher.aspects.persistence.HWTransactionManagement.transactionalMethods();

	expose :
		healthwatcher.aspects.concurrency.HWManagedSynchronization.synchronizationPoints(healthwatcher.model.employee.Employee);

	expose :
		healthwatcher.aspects.exceptionHandling.HWUpdateObserverExceptionHandler.updateObserver();
}

module data {
	class healthwatcher.data..*;
	friend healthwatcher.aspects.concurrency.HWLocalSynchronization;

	expose :
		healthwatcher.aspects.concurrency.HWTimestamp.insertComplaint(healthwatcher.model.complaint.Complaint);
	expose :
		healthwatcher.aspects.concurrency.HWTimestamp.searchComplaint(healthwatcher.model.complaint.Complaint);
	expose :
		healthwatcher.aspects.concurrency.HWTimestamp.updateComplaint(healthwatcher.model.complaint.Complaint, healthwatcher.data.rdb.ComplaintRepositoryRDB);
}

module model {
	class healthwatcher.model..*;
	friend healthwatcher.aspects.concurrency.HWTimestamp;

	expose :
		healthwatcher.aspects.patterns.complaintState.ComplaintStateAspect.complaintInit();
	expose :
		healthwatcher.aspects.patterns.complaintState.AnimalComplaintStateAspect.complaintInit();
	expose :
		healthwatcher.aspects.patterns.complaintState.FoodComplaintStateAspect.complaintInit();
	expose :
		healthwatcher.aspects.patterns.complaintState.SpecialComplaintStateAspect.complaintInit();

	expose :
		healthwatcher.aspects.patterns.complaintState.ComplaintStateAspect.complaintInitArgs();
	expose :
		healthwatcher.aspects.patterns.complaintState.AnimalComplaintStateAspect.complaintInitArgs();
	expose :
		healthwatcher.aspects.patterns.complaintState.FoodComplaintStateAspect.complaintInitArgs();
	expose :
		healthwatcher.aspects.patterns.complaintState.SpecialComplaintStateAspect.complaintInitArgs();

	expose :
		healthwatcher.aspects.patterns.complaintState.ComplaintStateAspect.setStatus(int, healthwatcher.model.complaint.Complaint);
	expose :
		healthwatcher.aspects.patterns.complaintState.AnimalComplaintStateAspect.setStatus(int, healthwatcher.model.complaint.AnimalComplaint);
	expose :
		execution(void healthwatcher.model.complaint.state.FoodComplaintState+.setStatus(int, healthwatcher.model.complaint.FoodComplaint));
	expose :
		execution(void healthwatcher.model.complaint.state.SpecialComplaintState+.setStatus(int, healthwatcher.model.complaint.SpecialComplaint));
}

module view {
	class healthwatcher.view..*;
	friend healthwatcher.aspects.patterns.ServletCommanding;
	friend healthwatcher.aspects.exceptionHandling.HWUpdateObserverExceptionHandler;

	expose :
		healthwatcher.aspects.exceptionHandling.HWDistributionExceptionHandler.servletGet(javax.servlet.http.HttpServletResponse);
	expose :
		healthwatcher.aspects.exceptionHandling.HWPersistenceExceptionHandler.servletGet(javax.servlet.http.HttpServletResponse);
	expose :
		healthwatcher.aspects.exceptionHandling.HWTransactionExceptionHandler.servletGet(javax.servlet.http.HttpServletResponse);

	expose :
		healthwatcher.aspects.distribution.HWClientDistribution.facadeMethods();

	expose :
		healthwatcher.aspects.patterns.ServletCommanding.servletInit();

	expose :
		healthwatcher.aspects.concurrency.HWTimestamp.executeCommand();

	expose :
		healthwatcher.aspects.exceptionHandling.HWUpdateObserverExceptionHandler.executeCommand();
}

module lib {
	class lib..*;

	expose :
		call(* lib.distribution.rmi.MethodExecutor.invoke(..));
	
	expose :
		healthwatcher.aspects.distribution.HWClientDistribution.iteratorDskMethods();

	expose :
		healthwatcher.aspects.persistence.HWTransactionManagement.persistenceMethods();

	expose :
		call(* lib.util.HTMLCode.*(..));

	expose :
		call(lib.distribution.rmi.IteratorRMISourceAdapter.new(..));

	expose :
		call(lib.distribution.rmi.IteratorRMITargetAdapter.new(..));

	expose :
		call(* lib.exceptions.*.*(..));

	expose :
		healthwatcher.aspects.patterns.ServletCommanding.commandTrigger(lib.patterns.CommandInvoker);
}

module CommandProtocolITD {
	friend lib.patterns.CommandProtocol;
	open lib;
	open view;
}

module UpdateStateObserverITD {
	friend healthwatcher.aspects.patterns.UpdateStateObserver;
	open model;
	open CommandProtocolITD;
}
